@@ -3,8 +3,8 @@
 import numpy as np
 from numpy import linalg as LA
 
-def stability_test(matrix, crystal_type):
 
+def stability_test(matrix, crystal_type, verbose=True):
     """This methods tests for the stability of a structure, then returns a boolean if ther structure is stable.
 
         References
@@ -14,33 +14,34 @@ def stability_test(matrix, crystal_type):
 
     c = np.copy(matrix)
     stable = True
+    to_print = ""
     if crystal_type == "cubic":
-        print("Cubic crystal system \n")
-        print(
+        to_print += ("Cubic crystal system \n")
+        to_print += (
             "Born stability criteria for the stability of cubic system are: Ref.[1]  \n"
         )
-        print("(i) C11 - C12 > 0;    (ii) C11 + 2C12 > 0;   (iii) C44 > 0 \n ")
+        to_print += ("(i) C11 - C12 > 0;    (ii) C11 + 2C12 > 0;   (iii) C44 > 0 \n ")
 
         # check (i)   keep in mind list starts with 0, so c11 is stored as c00
         if c[0][0] - c[0][1] > 0.0:
-            print("Condition (i) satisfied.")
+            to_print += ("Condition (i) satisfied.")
             condition1 = True
         else:
-            print("Condition (i) NOT satisfied.")
+            to_print += ("Condition (i) NOT satisfied.")
             condition1 = False
 
         if c[0][0] + 2 * c[0][1] > 0.0:
-            print("Condition (ii) satisfied.")
+            to_print += ("Condition (ii) satisfied.")
             condition2 = True
         else:
-            print("Condition (ii) NOT satisfied.")
+            to_print += ("Condition (ii) NOT satisfied.")
             condition2 = False
 
         if c[3][3] > 0.0:
-            print("Condition (iii) satisfied.")
+            to_print += ("Condition (iii) satisfied.")
             condition3 = True
         else:
-            print("Condition (iii) NOT satisfied.")
+            to_print += ("Condition (iii) NOT satisfied.")
             condition3 = False
 
         conditions = (condition1, condition2, condition3)
@@ -52,34 +53,34 @@ def stability_test(matrix, crystal_type):
         return stable
 
     if crystal_type == "hexagonal":
-        print("Hexagonal crystal system \n")
-        print(
+        to_print += ("Hexagonal crystal system \n")
+        to_print += (
             "Born stability criteria for the stability of hexagonal system are: Ref.[1]  \n"
         )
-        print(
+        to_print += (
             "(i) C11 - C12 > 0;    (ii) 2*C13^2 < C33(C11 + C12);   (iii) C44 > 0 \n "
         )
 
         # check (i)   keep in mind list starts with 0, so c11 is stored as c00
         if c[0][0] - c[0][1] > 0.0:
-            print("Condition (i) satisfied.")
+            to_print += ("Condition (i) satisfied.")
             condition1 = True
         else:
-            print("Condition (i) NOT satisfied.")
+            to_print += ("Condition (i) NOT satisfied.")
             condition1 = False
 
         if 2 * (c[0][2] * c[0][2]) < c[2][2] * (c[0][0] + c[0][1]):
-            print("Condition (ii) satified.")
+            to_print += ("Condition (ii) satified.")
             condition2 = True
         else:
-            print("Condition (ii) NOT satisfied.")
+            to_print += ("Condition (ii) NOT satisfied.")
             condition2 = False
 
         if c[3][3] > 0.0:
-            print("Condition (iii) satisfied.")
+            to_print += ("Condition (iii) satisfied.")
             condition3 = True
         else:
-            print("Condition (iii) NOT satisfied.")
+            to_print += ("Condition (iii) NOT satisfied.")
             condition3 = False
         conditions = (condition1, condition2, condition3)
 
@@ -88,89 +89,90 @@ def stability_test(matrix, crystal_type):
                 stable = False
 
     if crystal_type == "tetragonal":
-        print("Tetragonal crystal system \n")
-        print(
+        to_print += ("Tetragonal crystal system \n")
+        to_print += (
             "Born stability criteria for the stability of Tetragonal system are: Ref.[1]  \n"
         )
-        print(
+        to_print += (
             "(i) C11 - C12 > 0;    (ii) 2*C13^2 < C33(C11 + C12);   (iii) C44 > 0; \n(iv) C66 > 0;    (v) 2C16^2 < C66*(C11-C12) \n "
         )
 
         # check (i)   keep in mind list starts with 0, so c11 is stored as c00
         if c[0][0] - c[0][1] > 0.0:
-            print("Condition (i) is satisfied.")
+            to_print += ("Condition (i) is satisfied.")
             condition1 = True
         else:
-            print("Condition (i) is NOT satisfied.")
+            to_print += ("Condition (i) is NOT satisfied.")
             condition1 = False
 
         if 2 * (c[0][2] * c[0][2]) < c[2][2] * (c[0][0] + c[0][1]):
-            print("Condition (ii) is satisfied.")
+            to_print += ("Condition (ii) is satisfied.")
             condition2 = True
         else:
-            print("Condition (ii) is NOT satisfied.")
+            to_print += ("Condition (ii) is NOT satisfied.")
             condition2 = False
 
         if c[3][3] > 0.0:
-            print("Condition (iii) is satisfied.")
+            to_print += ("Condition (iii) is satisfied.")
             condition3 = True
         else:
-            print("Condition (iii) is NOT satisfied.")
+            to_print += ("Condition (iii) is NOT satisfied.")
             condition3 = False
 
         if c[5][5] > 0.0:
-            print("Condition (iv) is satisfied.")
+            to_print += ("Condition (iv) is satisfied.")
             condition4 = True
         else:
-            print("Condition (iv) is NOT satisfied.")
+            to_print += ("Condition (iv) is NOT satisfied.")
             condition4 = False
 
         if 2 * c[0][5] * c[0][5] < c[5][5] * (c[0][0] - c[0][1]):
-            print("Condition (v) is satisfied.")
+            to_print += ("Condition (v) is satisfied.")
             condition5 = True
         else:
-            print("Condition (v) is NOT satisfied.")
+            to_print += ("Condition (v) is NOT satisfied.")
             condition5 = False
 
-        conditions = (condition1, condition2, condition3, condition4, condition5)
+        conditions = (condition1, condition2,
+                      condition3, condition4, condition5)
 
         for condition in conditions:
             if condition == False:
                 stable = False
 
     if crystal_type == "rhombohedral-1":
-        print("Rhombohedral (class-1): point group: 3m, -3m and 32 \n")
-        print("Born stability criteria for this class are: Ref.[1]  \n")
-        print(
+        to_print += ("Rhombohedral (class-1): point group: 3m, -3m and 32 \n")
+        to_print += ("Born stability criteria for this class are: Ref.[1]  \n")
+        to_print += (
             "(i) C11 - C12 > 0;    (ii) C13^2 < (1/2)*C33(C11 + C12);   (iii) C14^2 < (1/2)*C44*(C11-C12) = C44*C66; \n(iv)  C44 > 0; \n "
         )
 
         if c[0][0] - c[0][1] > 0.0:
-            print("Condition (i) is satisfied.")
+            to_print += ("Condition (i) is satisfied.")
             condition1 = True
         else:
-            print("Condition (i) is NOT satisfied.")
+            to_print += ("Condition (i) is NOT satisfied.")
             condition1 = False
 
         if (c[0][2] * c[0][2]) < (0.5) * c[2][2] * (c[0][0] + c[0][1]):
-            print("Condition (ii) is satisfied.")
+            to_print += ("Condition (ii) is satisfied.")
             condition2 = True
         else:
-            print("Condition (ii) is NOT satisfied.")
+            to_print += ("Condition (ii) is NOT satisfied.")
             condition2 = False
 
         if c[0][3] * c[0][3] < 0.5 * c[3][3] * (c[0][0] - c[0][1]):
-            print("Condition (iii) is satisfied.")
+            to_print += ("Condition (iii) is satisfied.")
             condition3 = True
         else:
-            print("Condition (iii) is NOT satisfied.")
+            to_print += ("Condition (iii) is NOT satisfied.")
             condition3 = False
 
         if c[3][3] > 0.0:
-            print("Condition (iv) is satisfied.")
+            to_print += ("Condition (iv) is satisfied.")
             condition4 = True
         else:
-            print("Condition (iv) is NOT satisfied.")
+            to_print += ("Condition (iv) is NOT satisfied.")
             condition4 = False
 
         conditions = (condition1, condition2, condition3, condition4)
@@ -180,40 +182,40 @@ def stability_test(matrix, crystal_type):
                 stable = False
 
     if crystal_type == "rhombohedral-2":
-        print("Rhombohedral (class-2): i.e structures with point group: 3, -3 \n")
-        print(
+        to_print += ("Rhombohedral (class-2): i.e structures with point group: 3, -3 \n")
+        to_print += (
             "Born stability criteria for the stability of Rhombohedral-1 class system are: Ref.[1]  \n"
         )
-        print(
+        to_print += (
             "(i) C11 - C12 > 0;    (ii) C13^2 < (1/2)*C33(C11 + C12);   (iii) C14^2 + C15^2 < (1/2)*C44*(C11-C12) = C44*C66; \n(iv)  C44 > 0;  Note: C15 is added.. \n "
         )
 
         if c[0][0] - c[0][1] > 0.0:
-            print("Condition (i) is satisfied.")
+            to_print += ("Condition (i) is satisfied.")
             condition1 = True
         else:
-            print("Condition (i) is NOT satisfied.")
+            to_print += ("Condition (i) is NOT satisfied.")
             condition1 = False
 
         if c[0][2] * c[0][2] < (0.5) * c[2][2] * (c[0][0] + c[0][1]):
-            print("Condition (ii) is satisfied.")
+            to_print += ("Condition (ii) is satisfied.")
             condition2 = True
         else:
-            print("Condition (ii) is NOT satisfied.")
+            to_print += ("Condition (ii) is NOT satisfied.")
             condition2 = False
 
         if c[0][3] * c[0][3] + c[0][4] * c[0][4] < 0.5 * c[3][3] * (c[0][0] - c[0][1]):
-            print("Condition (iii) is satified.")
+            to_print += ("Condition (iii) is satified.")
             condition3 = True
         else:
-            print("Condition (iii) is NOT satisfied.")
+            to_print += ("Condition (iii) is NOT satisfied.")
             condition3 = False
 
         if c[3][3] > 0.0:
-            print("Condition (iv) is satisfied.")
+            to_print += ("Condition (iv) is satisfied.")
             condition4 = True
         else:
-            print("Condition (iv) is NOT satisfied.")
+            to_print += ("Condition (iv) is NOT satisfied.")
             condition4 = False
 
         conditions = (condition1, condition2, condition3, condition4)
@@ -223,27 +225,27 @@ def stability_test(matrix, crystal_type):
                 stable = False
 
     if crystal_type == "orthorhombic":
-        print("Orthorhombic crystal system.... \n")
-        print(
+        to_print += ("Orthorhombic crystal system.... \n")
+        to_print += (
             "Born stability criteria for the stability of Orthorhombic systems are: Ref.[1]  \n"
         )
-        print(
+        to_print += (
             "(i) C11 > 0;   (ii) C11*C22 > C12^2;   (iii) C11*C22*C33 + 2C12*C13*C23 - C11*C23^2 - C22*C13^2 - C33*C12^2 > 0; \n(iv)  C44 > 0;   (v)  C55 > 0 ;   (vi)  C66 > 0 \n"
         )
 
         # check (i)   keep in mind list starts with 0, so c11 is stored as c00
         if c[0][0] > 0.0:
-            print("Condition (i) is satisfied.")
+            to_print += ("Condition (i) is satisfied.")
             condition1 = True
         else:
-            print("Condition (i) is NOT satisfied.")
+            to_print += ("Condition (i) is NOT satisfied.")
             condition1 = False
 
         if c[0][0] * c[1][1] > c[0][1] * (c[0][1]):
-            print("Condition (ii) is satisfied.")
+            to_print += ("Condition (ii) is satisfied.")
             condition2 = True
         else:
-            print("Condition (ii) is NOT satisfied.")
+            to_print += ("Condition (ii) is NOT satisfied.")
             condition2 = False
 
         if (
@@ -254,31 +256,31 @@ def stability_test(matrix, crystal_type):
             - c[2][2] * c[0][1] * c[0][1]
             > 0
         ):
-            print("Condition (iii) is satisfied.")
+            to_print += ("Condition (iii) is satisfied.")
             condition3 = True
         else:
-            print("Condition (iii) is NOT satisfied.")
+            to_print += ("Condition (iii) is NOT satisfied.")
             condition3 = False
 
         if c[3][3] > 0.0:
-            print("Condition (iv) is satisfied.")
+            to_print += ("Condition (iv) is satisfied.")
             condition4 = True
         else:
-            print("Condition (iv) is NOT satisfied.")
+            to_print += ("Condition (iv) is NOT satisfied.")
             condition4 = False
 
         if c[4][4] > 0.0:
-            print("Condition (v) is satisfied.")
+            to_print += ("Condition (v) is satisfied.")
             condition5 = True
         else:
-            print("Condition (v) is NOT satisfied.")
+            to_print += ("Condition (v) is NOT satisfied.")
             condition5 = False
 
         if c[5][5] > 0.0:
-            print("Condition (vi) is satisfied.")
+            to_print += ("Condition (vi) is satisfied.")
             condition6 = True
         else:
-            print("Condition (vi) is NOT satisfied.")
+            to_print += ("Condition (vi) is NOT satisfied.")
             condition6 = False
 
         conditions = (
@@ -295,100 +297,100 @@ def stability_test(matrix, crystal_type):
                 stable = False
 
     if crystal_type == "monoclinic":
-        print("Monoclinic crystal system.... \n")
-        print(
+        to_print += ("Monoclinic crystal system.... \n")
+        to_print += (
             "Born stability criteria for the stability of monoclinic systems are: Ref.[1,2]  \n"
         )
-        print(
+        to_print += (
             "(i) C11 > 0;  (ii)  C22 > 0; (iii)  C33 > 0; \n(iv)  C44 > 0;   (v)  C55 > 0 ;   (vi)  C66 > 0  "
         )
-        print(
+        to_print += (
             " (vii) [C11 + C22 + C33 + 2*(C12 + C13 + C23)] > 0;    (viii)  C33*C55 - C35^2 > 0; \n(ix)  C44*C66 - C46^2 > 0;   (x) C22 + C33 - 2*C23  > 0 "
         )
-        print(
+        to_print += (
             " (xi) C22*(C33*C55 - C35^2) + 2*C23*C25*C35 - (C23^2)*C55 - (C25^2)*C33   > 0  "
         )
-        print(
+        to_print += (
             " (xii)  2*[C15*C25*(C33*C12 - C13*C23) + C15*C35*(C22*C13 - C12*C23) + C25*C35*(C11*C23 - C12*C13)] - [C15*C15*(C22*C33 - C23^2) + C25*C25*(C11*C33 - C13^2) + C35*C35*(C11*C22 - C12^2)] + C55*g > 0  "
         )
-        print(
+        to_print += (
             "          where, g = [C11*C22*C33 - C11*C23*C23 - C22*C13*C13 - C33*C12*C12 + 2*C12*C13*C23 ] "
         )
 
         if c[0][0] > 0.0:
-            print("Condition (i) is satisfied.")
+            to_print += ("Condition (i) is satisfied.")
             condition1 = True
         else:
-            print("Condition (i) is NOT satisfied.")
+            to_print += ("Condition (i) is NOT satisfied.")
             condition1 = False
 
         if c[1][1] > 0.0:
-            print("Condition (ii) is satisfied.")
+            to_print += ("Condition (ii) is satisfied.")
             condition2 = True
         else:
-            print("Condition (ii) is NOT satisfied.")
+            to_print += ("Condition (ii) is NOT satisfied.")
             condition2 = False
 
         if c[2][2] > 0.0:
-            print("Condition (iii) is satisfied.")
+            to_print += ("Condition (iii) is satisfied.")
             condition3 = True
         else:
-            print("Condition (iii) is NOT satisfied.")
+            to_print += ("Condition (iii) is NOT satisfied.")
             condition3 = False
 
         if c[3][3] > 0.0:
-            print("Condition (iv) is satisfied.")
+            to_print += ("Condition (iv) is satisfied.")
             condition4 = True
         else:
-            print("Condition (iv) is NOT satisfied.")
+            to_print += ("Condition (iv) is NOT satisfied.")
             condition4 = False
 
         if c[4][4] > 0.0:
-            print("Condition (v) is satisfied.")
+            to_print += ("Condition (v) is satisfied.")
             condition5 = True
         else:
-            print("Condition (v) is NOT satisfied.")
+            to_print += ("Condition (v) is NOT satisfied.")
             condition5 = False
 
         if c[5][5] > 0.0:
-            print("Condition (vi) is satisfied.")
+            to_print += ("Condition (vi) is satisfied.")
             condition6 = True
         else:
-            print("Condition (vi) is NOT satisfied.")
+            to_print += ("Condition (vi) is NOT satisfied.")
             condition6 = False
 
         # for i in range(0, 6):
         #    if(c[i][i]  > 0.0):
-        #        print("Condition (%2d) is satified." % (i+1))
+        #        to_print += ("Condition (%2d) is satified." % (i+1))
         #    else:
-        #        print("Condition (%2d) is NOT satified." % (i+1))
+        #        to_print += ("Condition (%2d) is NOT satified." % (i+1))
 
         if c[0][0] + c[1][1] + c[2][2] + 2 * (c[0][1] + c[0][2] + c[1][2]) > 0:
-            print("Condition (vii) is satisfied.")
+            to_print += ("Condition (vii) is satisfied.")
             condition7 = True
         else:
-            print("Condition (vii) is NOT satisfied.")
+            to_print += ("Condition (vii) is NOT satisfied.")
             condition7 = False
 
         if c[2][2] * c[4][4] - c[2][4] * c[2][4] > 0:
-            print("Condition (viii) is satisfied.")
+            to_print += ("Condition (viii) is satisfied.")
             condition8 = True
         else:
-            print("Condition (viii) is NOT satisfied.")
+            to_print += ("Condition (viii) is NOT satisfied.")
             condition8 = False
 
         if c[3][3] * c[5][5] - c[3][5] * c[3][5] > 0.0:
-            print("Condition (ix) is satisfied.")
+            to_print += ("Condition (ix) is satisfied.")
             condition9 = True
         else:
-            print("Condition (ix) is NOT satisfied.")
+            to_print += ("Condition (ix) is NOT satisfied.")
             condition9 = False
 
         if c[1][1] + c[2][2] - 2 * c[1][2] > 0.0:
-            print("Condition (x) is satisfied.")
+            to_print += ("Condition (x) is satisfied.")
             condition10 = True
         else:
-            print("Condition (x) is NOT satisfied.")
+            to_print += ("Condition (x) is NOT satisfied.")
             condition10 = False
 
         if (
@@ -398,10 +400,10 @@ def stability_test(matrix, crystal_type):
             - c[1][4] * c[1][4] * c[2][2]
             > 0.0
         ):
-            print("Condition (xi) is satisfied.")
+            to_print += ("Condition (xi) is satisfied.")
             condition11 = True
         else:
-            print("Condition (xi) is NOT satisfied.")
+            to_print += ("Condition (xi) is NOT satisfied.")
             condition11 = False
 
         g = (
@@ -426,14 +428,14 @@ def stability_test(matrix, crystal_type):
 
         x = h1 - h2 + c[4][4] * g
 
-        #  print 'x = %10.4f' % x
-        #  print 'g = %10.4f' % g
+        #  to_print +=  'x = %10.4f' % x
+        #  to_print +=  'g = %10.4f' % g
 
         if x > 0.0:
-            print("Condition (xii) is satisfied.")
+            to_print += ("Condition (xii) is satisfied.")
             condition12 = True
         else:
-            print("Condition (xii) is NOT satisfied.")
+            to_print += ("Condition (xii) is NOT satisfied.")
             condition12 = False
         conditions = (
             condition1,
@@ -454,16 +456,14 @@ def stability_test(matrix, crystal_type):
             if condition == False:
                 stable = False
 
-
-
     if crystal_type == "triclinic":
-        print("Triclinic crystal system.... \n")
-        print(
+        to_print += ("Triclinic crystal system.... \n")
+        to_print += (
             "Triclinic systems only criteria for stability are positive eigen values of the elastic tensor  \n"
         )
         evals = list(LA.eigvals(c))
-        evalsPrint = list(np.around(np.array(evals), 3))
-        print("%s" % evalsPrint)
+        evals_print = list(np.around(np.array(evals), 3))
+        to_print += ("%s" % evals_print)
         check = 0
         for i in range(len(evals)):
             if evals[i] > 0.0:
@@ -473,50 +473,45 @@ def stability_test(matrix, crystal_type):
                 check = 1
                 stable = False
 
-
-
-
+    if verbose:
+        print(to_print)
     return stable
 
 
+def stability_test_2d(matrix, lattice_type, verbose):
+    c = np.zeros(shape=(3, 3))
 
+    c[0, 0] = matrix[0, 0]
+    c[0, 1] = matrix[0, 1]
+    c[0, 2] = matrix[0, 5]
 
+    c[1, 0] = matrix[1, 0]
+    c[1, 1] = matrix[1, 1]
+    c[1, 2] = matrix[1, 5]
 
+    c[2, 0] = matrix[5, 0]
+    c[2, 1] = matrix[5, 1]
+    c[2, 2] = matrix[5, 5]
 
-
-def stability_test_2d(matrix, lattice_type):
-    c = np.zeros(shape = (3,3))
-    
-    c[0,0] = matrix[0,0]
-    c[0,1] = matrix[0,1]
-    c[0,2] = matrix[0,5]
-    
-    c[1,0] = matrix[1,0]
-    c[1,1] = matrix[1,1]
-    c[1,2] = matrix[1,5]
-    
-    c[2,0] = matrix[5,0]
-    c[2,1] = matrix[5,1]
-    c[2,2] = matrix[5,5]
-    
     stable = True
+    to_print = ""
     if lattice_type == "hexagonal":
-        print("Hexagonal lattice \n")
-        print("Stability criteria for the stability of hexagonal system are: \n")
-        print("(i) C11 + C12 > 0;    (ii) C11 - C12 > 0;  \n ")
+        to_print += ("Hexagonal lattice \n")
+        to_print += ("Stability criteria for the stability of hexagonal system are: \n")
+        to_print += ("(i) C11 + C12 > 0;    (ii) C11 - C12 > 0;  \n ")
 
         if c[0][0] + c[0][1] > 0.0:
-            print("Condition (i) satisfied.")
+            to_print += ("Condition (i) satisfied.")
             condition1 = True
         else:
-            print("Condition (i) NOT satisfied.")
+            to_print += ("Condition (i) NOT satisfied.")
             condition1 = False
 
         if c[0][0] - c[0][1] > 0.0:
-            print("Condition (ii) satisfied.")
+            to_print += ("Condition (ii) satisfied.")
             condition2 = True
         else:
-            print("Condition (ii) NOT satisfied.")
+            to_print += ("Condition (ii) NOT satisfied.")
             condition2 = False
 
         conditions = (condition1, condition2)
@@ -525,32 +520,30 @@ def stability_test_2d(matrix, lattice_type):
             if condition == False:
                 stable = False
 
-        return stable
-
-    if lattice_type == "square":
-        print("Square lattice \n")
-        print("Stability criteria for the stability of square system are: \n")
-        print("(i) C11 + C12 > 0;    (ii) C11 - C12 > 0;  (iii) C33 > 0     \n ")
+    elif lattice_type == "square":
+        to_print += ("Square lattice \n")
+        to_print += ("Stability criteria for the stability of square system are: \n")
+        to_print += ("(i) C11 + C12 > 0;    (ii) C11 - C12 > 0;  (iii) C33 > 0     \n ")
 
         if c[0][0] + c[0][1] > 0.0:
-            print("Condition (i) satisfied.")
+            to_print += ("Condition (i) satisfied.")
             condition1 = True
         else:
-            print("Condition (i) NOT satisfied.")
+            to_print += ("Condition (i) NOT satisfied.")
             condition1 = False
 
         if c[0][0] - c[0][1] > 0.0:
-            print("Condition (ii) satisfied.")
+            to_print += ("Condition (ii) satisfied.")
             condition2 = True
         else:
-            print("Condition (ii) NOT satisfied.")
+            to_print += ("Condition (ii) NOT satisfied.")
             condition2 = False
 
         if c[2][2] > 0.0:
-            print("Condition (iii) satisfied.")
+            to_print += ("Condition (iii) satisfied.")
             condition3 = True
         else:
-            print("Condition (iii) NOT satisfied.")
+            to_print += ("Condition (iii) NOT satisfied.")
             condition3 = False
 
         conditions = (condition1, condition2, condition3)
@@ -559,14 +552,12 @@ def stability_test_2d(matrix, lattice_type):
             if condition == False:
                 stable = False
 
-        return stable
-
-    if lattice_type == "rectangular" or lattice_type == "rectangular-center":
-        print("Rectangular lattice or Rectangular Center lattice \n")
-        print(
+    elif lattice_type == "rectangular" or lattice_type == "rectangular-center":
+        to_print += ("Rectangular lattice or Rectangular Center lattice \n")
+        to_print += (
             "Stability criteria for the stability of rectangular lattice or rectangular Center lattic are: \n"
         )
-        print(
+        to_print += (
             "(i) 1/2*(C11 + C22 + (4(C12)**2 - (C11 -C22))**0.5)> 0;    (ii) 1/2*(C11 + C22 - (4(C12)**2 - (C11 -C22))**0.5)> 0 ;  (iii) C33 > 0     \n "
         )
 
@@ -579,10 +570,10 @@ def stability_test_2d(matrix, lattice_type):
             )
             > 0.0
         ):
-            print("Condition (i) satisfied.")
+            to_print += ("Condition (i) satisfied.")
             condition1 = True
         else:
-            print("Condition (i) NOT satisfied.")
+            to_print += ("Condition (i) NOT satisfied.")
             condition1 = False
 
         if (
@@ -594,17 +585,17 @@ def stability_test_2d(matrix, lattice_type):
             )
             > 0.0
         ):
-            print("Condition (ii) satisfied.")
+            to_print += ("Condition (ii) satisfied.")
             condition2 = True
         else:
-            print("Condition (ii) NOT satisfied.")
+            to_print += ("Condition (ii) NOT satisfied.")
             condition2 = False
 
         if c[2][5] > 0.0:
-            print("Condition (iii) satisfied.")
+            to_print += ("Condition (iii) satisfied.")
             condition3 = True
         else:
-            print("Condition (iii) NOT satisfied.")
+            to_print += ("Condition (iii) NOT satisfied.")
             condition3 = False
 
         conditions = (condition1, condition2, condition3)
@@ -613,32 +604,30 @@ def stability_test_2d(matrix, lattice_type):
             if condition == False:
                 stable = False
 
-        return stable
-
-    if lattice_type == "oblique":
-        print("Oblique lattice \n")
-        print("Stability criteria for the stability of oblique lattice are: \n")
-        print("(i) C11 > 0 ;    (ii) C11 *C22 > (C12)*2 ;  (iii) det(Cij) > 0     \n ")
+    elif lattice_type == "oblique":
+        to_print += ("Oblique lattice \n")
+        to_print += ("Stability criteria for the stability of oblique lattice are: \n")
+        to_print += ("(i) C11 > 0 ;    (ii) C11 *C22 > (C12)*2 ;  (iii) det(Cij) > 0     \n ")
 
         if c[0][0] > 0.0:
-            print("Condition (i) satisfied.")
+            to_print += ("Condition (i) satisfied.")
             condition1 = True
         else:
-            print("Condition (i) NOT satisfied.")
+            to_print += ("Condition (i) NOT satisfied.")
             condition1 = False
 
         if c[0][0] * c[1][1] > (c[0][1]) ** 2:
-            print("Condition (ii) satisfied.")
+            to_print += ("Condition (ii) satisfied.")
             condition2 = True
         else:
-            print("Condition (ii) NOT satisfied.")
+            to_print += ("Condition (ii) NOT satisfied.")
             condition2 = False
 
         if np.linalg.det(c) > 0.0:
-            print("Condition (iii) satisfied.")
+            to_print += ("Condition (iii) satisfied.")
             condition3 = True
         else:
-            print("Condition (iii) NOT satisfied.")
+            to_print += ("Condition (iii) NOT satisfied.")
             condition3 = False
 
         conditions = (condition1, condition2, condition3)
@@ -646,5 +635,9 @@ def stability_test_2d(matrix, lattice_type):
         for condition in conditions:
             if condition == False:
                 stable = False
+    else:
+        raise NameError("lattice type %s not in recognized" % lattice_type)
 
-        return stable
+    if verbose:
+        print(to_print)
+    return stable
